﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using DTMF_IVR_WinForm;
using DTMF_IVR_WinForm.Model;
using Ozeki.VoIP;

namespace DTMF_IVR_WinForm
{
    public partial class FormIVRMain : Form
    {

        private IVREngine ivrEngine;
        private SIPAccount sipAccount;
        private List<IVRMenuElement> treeViewList;

        public FormIVRMain()
        {
            InitializeComponent();
            sipAccount=new SIPAccount(true,"oz875","oz875","oz875","oz875","192.168.112.100");
      //      sipAccount = new SIPAccount(true, "875", "875", "875", "875", "192.168.112.101");
            txtLog.Text += string.Format("Trying to register {0} with {1}{2}",sipAccount.DomainServerHost, sipAccount.RegisterName, Environment.NewLine) ;
            txtLog.Text += string.Format("SIPAccount {0}@{1} {2}", sipAccount.UserName, sipAccount.DomainServerHost, Environment.NewLine);
        }

        private void FormIVRMain_Load(object sender, EventArgs e)
        {
            
            Tssl_Ozeki.Text = string.Format("© Copyright {0}, Ozeki Informatics Ltd.", DateTime.Now.Year);
            InitializeIVREngine();

            treeViewList = new IVRMenuBuilder().GetAllMenuElements();
            PopulateTreeView(-1,null);
        }

        private void InitializeIVREngine()
        {
            try
            {
                txtLog.Text += string.Format("IVR engine Initialization {0}", Environment.NewLine);
                ivrEngine=new IVREngine(sipAccount);
                ivrEngine.NotifyAction += new EventHandler<Ozeki.Common.GenericEventArgs<string>>(ivrEngine_NotifyAction);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        void ivrEngine_NotifyAction(object sender, Ozeki.Common.GenericEventArgs<string> e)
        {
            BeginInvoke((Action)(() => { txtLog.Text += e.Item + Environment.NewLine; }));
        }


        private void PopulateTreeView(int parentId, TreeNode parentNode)
        {
            var filteredItems = treeViewList.Where(item =>
                                        item.parentId == parentId);
           
            TreeNode childNode;
            foreach (var i in filteredItems.ToList())
            {
                if (parentNode == null)
                    childNode = treeView1.Nodes.Add(i.introduction);
                else
                    childNode = parentNode.Nodes.Add(string.Format("DTMF key: {0} - {1}",i.actionKey,i.introduction));

                PopulateTreeView(i.id, childNode);
            }
        }

        #region Menu events
        private void Tsmi_HelpPage_Click(object sender, EventArgs e)
        {
            try
            {
                Process.Start("http://www.voip-sip-sdk.com/");
            }
            catch (Exception exception)
            {
                Debug.WriteLine(exception);
            }
        }

        private void Tsmi_About_Click(object sender, EventArgs e)
        {
            AboutBox aboutBox = new AboutBox();

            aboutBox.ShowDialog(this);
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        #endregion



    }
}
